#[non_exhaustive]pub enum DataDirection {
None,
Read,
Write,
}Expand description
Direction of the data phase that follows a command, if any.
Marked #[non_exhaustive]: bidirectional / control-stream variants may be
added before 1.0.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No data phase follows this command.
Read
The host reads data from the card after the command response.
Write
The host writes data to the card after the command response.
Implementations