Skip to main contentModule response
Source - CidResponse
- CID register (CMD2/CMD10 response). Identifies the card’s manufacturer,
product, serial number, and manufacturing date.
- CsdResponse
- CSD register (CMD9 response, raw 16 bytes MSB-first as delivered by both
SPI and SDIO transports).
- IfCondResponse
- R7: Interface condition response
- OcrResponse
- OCR register (R3/CMD58 response)
- R1Response
- R1: Standard response — contains status bits
- RawResponse
- Raw response words harvested by a host controller.
- RcaResponse
- R6: Published RCA response
- SdioOcrResponse
- SDIO OCR (R4/CMD5 response)
- SdioRwResponse
- SDIO R5 response
- SwitchStatus
- 64-byte SD function-switch status, returned in the data phase of CMD6.
- CardState
- Card state machine states
- Response
- Parsed response from the card
- ResponseType
- Command response shape expected from the card.
- response_from_raw
- Parse normalized physical response words into the protocol response type.